@@ -42,6 +42,17 @@ describe Parallel do
         (1..999).should include(Parallel.processor_count)
       end
     end
+
+    if RUBY_VERSION.to_f >= 2.2
+      it 'uses Etc.nprocessors in Ruby 2.2+' do
+        defined?(Etc).should == "constant" 
+        Etc.respond_to?(:nprocessors).should == true 
+      end
+    else
+      it 'doesnt use Etc.nprocessors in Ruby 2.1 and below' do
+        defined?(Etc).should == "constant"
+      end
+    end
   end
 
   describe ".physical_processor_count" do
@@ -154,7 +165,15 @@ describe Parallel do
     end
 
     it "can raise an undumpable exception" do
-      `ruby spec/cases/parallel_raise_undumpable.rb`.strip.should include('Undumpable Exception')
+      out = `ruby spec/cases/parallel_raise_undumpable.rb`.strip
+      out.sub!(Dir.pwd, '.') # relative paths
+      out.gsub!(/(\d+)\:.*/, "\\1") # no diff in ruby version xyz.rb:123:in `block in <main>'
+      out.should == "MyException: MyException\nBACKTRACE: spec/cases/parallel_raise_undumpable.rb:12"
+    end
+
+    it "can handle Break exceptions when the better_errors gem is installed" do
+      out = `ruby spec/cases/parallel_break_better_errors.rb`.strip
+      out.should == "NOTHING WAS RAISED"
     end
 
     it 'can handle to high fork rate' do
@@ -384,15 +403,16 @@ describe Parallel do
     end
 
     it 'can work in isolation' do
+      skip if ENV['TRAVIS'] # this randomly hangs on travis
       out = `ruby spec/cases/map_isolation.rb`
       out.should == "1\n2\n3\n4\nOK"
     end
 
     it 'sets Parallel.worker_number when run with isolation' do
+      skip if ENV['TRAVIS'] # this randomly hangs on travis
       out = `ruby spec/cases/map_worker_number_isolation.rb`
       out.should == "0,1\nOK"
     end
-
   end
 
   describe ".map_with_index" do
@@ -415,6 +435,26 @@ describe Parallel do
     end
   end
 
+  describe ".any?" do
+    it "returns true if any result is truthy" do
+      `ruby spec/cases/any_true.rb`.split(',').should == ['true'] * 3 * 2
+    end
+
+    it "returns false if all results are falsy" do
+      `ruby spec/cases/any_false.rb`.split(',').should == ['false'] * 3 * 3
+    end
+  end
+
+  describe ".all?" do
+    it "returns true if all results are truthy" do
+      `ruby spec/cases/all_true.rb`.split(',').should == ['true'] * 3 * 3
+    end
+
+    it "returns false if any result is falsy" do
+      `ruby spec/cases/all_false.rb`.split(',').should == ['false'] * 3 * 2
+    end
+  end
+
   describe ".each" do
     it "returns original array, works like map" do
       `ruby spec/cases/each.rb`.should == 'a b c d'
@@ -458,7 +498,7 @@ describe Parallel do
       end
 
       it "stops all workers when one raises Break in #{type}" do
-        `METHOD=each WORKER_TYPE=#{type} ruby spec/cases/with_break.rb 2>&1`.should =~ /^\d{4} Parallel::Break raised - result 1\.\.100$/
+        `METHOD=each WORKER_TYPE=#{type} ruby spec/cases/with_break.rb 2>&1`.should =~ /^\d{4} Parallel::Break raised - result nil$/
       end
 
       it "stops all workers when a start hook fails with #{type}" do
@@ -487,6 +527,16 @@ describe Parallel do
         %w(0 1 2 3).each { |number| out.should include number }
       end
     end
+
+    it "re-raises exceptions in work_direct" do
+      `METHOD=each WORKER_TYPE=threads WORKER_SIZE=0 ruby spec/cases/with_exception.rb 2>&1`
+        .should =~ /^1 raised$/
+    end
+
+    it "handles Break in work_direct" do
+      `METHOD=each WORKER_TYPE=threads WORKER_SIZE=0 ruby spec/cases/with_break.rb 2>&1`
+        .should =~ /^1 Parallel::Break raised - result nil$/
+    end
   end
 
   describe ".each_with_index" do
@@ -546,7 +596,7 @@ describe Parallel do
     worker_types.each do |type|
       it "does not leak memory in #{type}" do
         pending if RUBY_ENGINE == 'jruby' # lots of objects ... GC does not seem to work ...
-        result = `ruby #{"-X+O" if RUBY_ENGINE == 'jruby'} spec/cases/profile_memroy.rb #{type} 2>&1`.strip.split("\n").last
+        result = `ruby #{"-X+O" if RUBY_ENGINE == 'jruby'} spec/cases/profile_memory.rb #{type} 2>&1`.strip.split("\n").last
         normalize(result).should == []
       end
     end
